@@ -85,7 +85,7 @@ class WechatPlugin(notify.NotificationPlugin):
             'help': 'Enter wechat robot url.',
             'placeholder': 'https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=xxx-xxx-xxx-xxx-xxx',
             'validators': [validate_urls],
-            'required': False
+            'required': True
         }]
 
     def get_webhook_urls(self, project):
